searchNodes=[{"ref":"UTCDateTime.html","title":"UTCDateTime","type":"module","doc":"A datetime implementation constraint to UTC."},{"ref":"UTCDateTime.html#add/3","title":"UTCDateTime.add/3","type":"function","doc":"Adds a specified amount of time to a UTCDateTime. Accepts an amount_to_add in any unit available from System.time_unit/0. Negative values will move the utc_datetime backwards in time. Examples # adds seconds by default iex&gt; UTCDateTime.add(~Z[2014-10-02 00:29:10], 2) ~Z[2014-10-02 00:29:12] # accepts negative offsets iex&gt; UTCDateTime.add(~Z[2014-10-02 00:29:10], -2) ~Z[2014-10-02 00:29:08] # can work with other units iex&gt; UTCDateTime.add(~Z[2014-10-02 00:29:10], 2_000, :millisecond) ~Z[2014-10-02 00:29:12] # keeps the same precision iex&gt; UTCDateTime.add(~Z[2014-10-02 00:29:10.021], 21, :second) ~Z[2014-10-02 00:29:31.021] # changes below the precision will not be visible iex&gt; hidden = UTCDateTime.add(~Z[2014-10-02 00:29:10], 21, :millisecond) iex&gt; hidden.microsecond # ~Z[2014-10-02 00:29:10] {21000, 0} # from Gregorian seconds iex&gt; UTCDateTime.add(~Z[0000-01-01 00:00:00], 63_579_428_950) ~Z[2014-10-02 00:29:10]"},{"ref":"UTCDateTime.html#compare/2","title":"UTCDateTime.compare/2","type":"function","doc":"Compares two UTCDateTime structs. Returns :gt if first (utc_datetime1) is later than the second (utc_datetime2) and :lt for vice versa. If the two UTCDateTime are equal :eq is returned. Examples iex&gt; UTCDateTime.compare(~Z[2016-04-16 13:30:15], ~Z[2016-04-28 16:19:25]) :lt iex&gt; UTCDateTime.compare(~Z[2016-04-16 13:30:15.1], ~Z[2016-04-16 13:30:15.01]) :gt iex&gt; UTCDateTime.compare(~Z[2016-04-16 13:30:15.654321], ~Z[2016-04-16 13:30:15.654321]) :eq"},{"ref":"UTCDateTime.html#diff/3","title":"UTCDateTime.diff/3","type":"function","doc":"Subtracts utc_datetime1 from utc_datetime2. The answer can be returned in any unit available from System.time_unit/0. This function returns the difference in seconds where seconds are measured according to Calendar.ISO. Examples iex&gt; UTCDateTime.diff(~Z[2014-10-02 00:29:12], ~Z[2014-10-02 00:29:10]) 2 iex&gt; UTCDateTime.diff(~Z[2014-10-02 00:29:12], ~Z[2014-10-02 00:29:10], :microsecond) 2_000_000 iex&gt; UTCDateTime.diff(~Z[2014-10-02 00:29:10.042], ~Z[2014-10-02 00:29:10.021], :millisecond) 21 iex&gt; UTCDateTime.diff(~Z[2014-10-02 00:29:10], ~Z[2014-10-02 00:29:12]) -2 iex&gt; UTCDateTime.diff(~Z[-0001-10-02 00:29:10], ~Z[-0001-10-02 00:29:12]) -2 # to Gregorian seconds iex&gt; UTCDateTime.diff(~Z[2014-10-02 00:29:10], ~Z[0000-01-01 00:00:00]) 63579428950"},{"ref":"UTCDateTime.html#epoch/1","title":"UTCDateTime.epoch/1","type":"function","doc":"A UTCDateTime representing the given epoch. Epochs EpochDateAliases :go0001-01-01:dotnet, :rata_die, :rexx :uuid1582-10-15 :win1601-01-01:win_nt, :win32, :cobol, :ntfs :mumps1840-12-31 :vms1858-11-17:vms, :usno, :dvb, :mjd :pascal1899-12-30:ms_com, :libre_office_calc, :google_sheets :ms_c1899-12-31:dyalog_alp :ms_excel1900-01-00:ms_excel, :lotus :unix1970-01-01:posix Examples iex&gt; UTCDateTime.epoch(:unix) ~Z[1970-01-01 00:00:00] iex&gt; UTCDateTime.epoch(:win) ~Z[1601-01-01 00:00:00] iex&gt; UTCDateTime.epoch(:go) ~Z[0001-01-01 00:00:00]"},{"ref":"UTCDateTime.html#from_date/2","title":"UTCDateTime.from_date/2","type":"function","doc":"Converts a Date into UTCDateTime. Because Date does not hold time information, it is possible to supply a Time to set on the given Date. If no Time is supplied the UTCDateTime will default to: 00:00:00. Examples iex&gt; UTCDateTime.from_date(~D[2002-01-13]) ~Z[2002-01-13 00:00:00] iex&gt; UTCDateTime.from_date(~D[2002-01-13], ~T[23:00:07]) ~Z[2002-01-13 23:00:07]"},{"ref":"UTCDateTime.html#from_datetime/1","title":"UTCDateTime.from_datetime/1","type":"function","doc":"Converts the given datetime into a UTCDateTime. Any datetime with a none UTC time zone will be converted to UTC. Examples iex&gt; dt = %DateTime{year: 2000, month: 2, day: 29, zone_abbr: &quot;UTC&quot;, ...&gt; hour: 23, minute: 0, second: 7, microsecond: {0, 1}, ...&gt; utc_offset: 0, std_offset: 0, time_zone: &quot;Etc/UTC&quot;} iex&gt; UTCDateTime.from_datetime(dt) ~Z[2000-02-29 23:00:07.0] iex&gt; dt = %DateTime{year: 2000, month: 2, day: 29, zone_abbr: &quot;CET&quot;, ...&gt; hour: 23, minute: 0, second: 7, microsecond: {0, 1}, ...&gt; utc_offset: 3600, std_offset: 0, time_zone: &quot;Europe/Warsaw&quot;} iex&gt; UTCDateTime.from_datetime(dt) ~Z[2000-02-29 22:00:07.0]"},{"ref":"UTCDateTime.html#from_erl/2","title":"UTCDateTime.from_erl/2","type":"function","doc":"Converts a erl_datetime (Erlang datetime tuple) to UTCDateTime. A tuple of microsecond (precision) can additionally be given to extend the datetime. Examples iex&gt; UTCDateTime.from_erl({{2000, 1, 1}, {13, 30, 15}}) {:ok, ~Z[2000-01-01 13:30:15]} iex&gt; UTCDateTime.from_erl({{2000, 1, 1}, {13, 30, 15}}, {5000, 3}) {:ok, ~Z[2000-01-01 13:30:15.005]} iex&gt; UTCDateTime.from_erl({{2000, 13, 1}, {13, 30, 15}}) {:error, :invalid_month} iex&gt; UTCDateTime.from_erl({{2000, 12, 32}, {13, 30, 15}}) {:error, :invalid_day} iex&gt; UTCDateTime.from_erl({{2000, 12, 31}, {25, 30, 15}}) {:error, :invalid_hour} iex&gt; UTCDateTime.from_erl({{2000, 12, 31}, {13, 61, 15}}) {:error, :invalid_minute} iex&gt; UTCDateTime.from_erl({{2000, 12, 31}, {13, 30, 61}}) {:error, :invalid_second}"},{"ref":"UTCDateTime.html#from_erl!/2","title":"UTCDateTime.from_erl!/2","type":"function","doc":"Converts a erl_datetime (Erlang datetime tuple) to UTCDateTime. Raises if the datetime is invalid. A tuple of microsecond (precision) can additionally be given to extend the datetime. Examples iex&gt; UTCDateTime.from_erl!({{2000, 1, 1}, {13, 30, 15}}) ~Z[2000-01-01 13:30:15] iex&gt; UTCDateTime.from_erl!({{2000, 1, 1}, {13, 30, 15}}, {5000, 3}) ~Z[2000-01-01 13:30:15.005] iex&gt; UTCDateTime.from_erl!({{2000, 13, 1}, {13, 30, 15}}) ** (ArgumentError) cannot convert {{2000, 13, 1}, {13, 30, 15}} to UTC datetime, reason: :invalid_month"},{"ref":"UTCDateTime.html#from_iso8601/1","title":"UTCDateTime.from_iso8601/1","type":"function","doc":"Parses the extended &quot;Date and time of day&quot; format described by ISO 8601:2004. Time zone offset may be included in the string but they will be converted to UTC time and stored as such. The year parsed by this function is limited to four digits and, while ISO 8601 allows datetimes to specify 24:00:00 as the zero hour of the next day, this notation is not supported by Elixir. Note leap seconds are not supported. Examples iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23t23:50:07&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23 23:50:07&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07Z&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.0&quot;) {:ok, ~Z[2015-01-23 23:50:07.0]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07,0123456&quot;) {:ok, ~Z[2015-01-23 23:50:07.012345]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.0123456&quot;) {:ok, ~Z[2015-01-23 23:50:07.012345]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123Z&quot;) {:ok, ~Z[2015-01-23 23:50:07.123]} iex&gt; UTCDateTime.from_iso8601(&quot;2016-02-29T23:50:07&quot;) {:ok, ~Z[2016-02-29 23:50:07]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23P23:50:07&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_iso8601(&quot;2015:01:23 23-50-07&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23 23:50:07A&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T24:50:07&quot;) {:error, :invalid_hour} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:61:07&quot;) {:error, :invalid_minute} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:61&quot;) {:error, :invalid_second} iex&gt; UTCDateTime.from_iso8601(&quot;2015-13-12T23:50:07&quot;) {:error, :invalid_month} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-32T23:50:07&quot;) {:error, :invalid_day} iex&gt; UTCDateTime.from_iso8601(&quot;2015-02-29T23:50:07&quot;) {:error, :invalid_day} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123+02:30&quot;) {:ok, ~Z[2015-01-23 21:20:07.123]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123+00:00&quot;) {:ok, ~Z[2015-01-23 23:50:07.123]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123-02:30&quot;) {:ok, ~Z[2015-01-24 02:20:07.123]} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123-00:00&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123-00:60&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_iso8601(&quot;2015-01-23T23:50:07.123-24:00&quot;) {:error, :invalid_format}"},{"ref":"UTCDateTime.html#from_iso8601!/1","title":"UTCDateTime.from_iso8601!/1","type":"function","doc":"Parses the extended &quot;Date and time of day&quot; format described by ISO 8601:2004. Raises if the format is invalid. For more examples see: from_iso8601/1. Examples iex&gt; UTCDateTime.from_iso8601!(&quot;2015-01-23T23:50:07.123Z&quot;) ~Z[2015-01-23 23:50:07.123] iex&gt; UTCDateTime.from_iso8601!(&quot;2015-01-23T23:50:07,123Z&quot;) ~Z[2015-01-23 23:50:07.123] iex&gt; UTCDateTime.from_iso8601!(&quot;2015-01-23P23:50:07&quot;) ** (ArgumentError) cannot parse &quot;2015-01-23P23:50:07&quot; as UTC datetime, reason: :invalid_format"},{"ref":"UTCDateTime.html#from_naive/1","title":"UTCDateTime.from_naive/1","type":"function","doc":"Converts the given NaiveDateTime to UTCDateTime. It expects the given naive_datetime to be in the &quot;Etc/UTC&quot; time zone. Examples iex&gt; UTCDateTime.from_naive(~N[2016-05-24 13:26:08.003]) ~Z[2016-05-24 13:26:08.003]"},{"ref":"UTCDateTime.html#from_rfc3339/1","title":"UTCDateTime.from_rfc3339/1","type":"function","doc":"Parses the extended &quot;Date and time of day&quot; format described by RFC 3339. Time zone offset may be included in the string but they will be converted to UTC time and stored as such. The year parsed by this function is limited to four digits and, while RFC 3339 allows datetimes to specify 24:00:00 as the zero hour of the next day, this notation is not supported. Passing -00:00 as undefined timezone is also not supported and will be interpreted as UTC. Note leap seconds are not supported. Examples iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23t23:50:07&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07Z&quot;) {:ok, ~Z[2015-01-23 23:50:07]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.0&quot;) {:ok, ~Z[2015-01-23 23:50:07.0]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07,0123456&quot;) {:ok, ~Z[2015-01-23 23:50:07.012345]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.0123456&quot;) {:ok, ~Z[2015-01-23 23:50:07.012345]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123Z&quot;) {:ok, ~Z[2015-01-23 23:50:07.123]} iex&gt; UTCDateTime.from_rfc3339(&quot;2016-02-29T23:50:07&quot;) {:ok, ~Z[2016-02-29 23:50:07]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23P23:50:07&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_rfc3339(&quot;2015:01:23 23-50-07&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23 23:50:07A&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T24:50:07&quot;) {:error, :invalid_hour} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:61:07&quot;) {:error, :invalid_minute} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:61&quot;) {:error, :invalid_second} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-13-12T23:50:07&quot;) {:error, :invalid_month} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-32T23:50:07&quot;) {:error, :invalid_day} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-02-29T23:50:07&quot;) {:error, :invalid_day} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123+02:30&quot;) {:ok, ~Z[2015-01-23 21:20:07.123]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123+00:00&quot;) {:ok, ~Z[2015-01-23 23:50:07.123]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123-02:30&quot;) {:ok, ~Z[2015-01-24 02:20:07.123]} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123-00:00&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123-00:60&quot;) {:error, :invalid_format} iex&gt; UTCDateTime.from_rfc3339(&quot;2015-01-23T23:50:07.123-24:00&quot;) {:error, :invalid_format}"},{"ref":"UTCDateTime.html#from_rfc3339!/1","title":"UTCDateTime.from_rfc3339!/1","type":"function","doc":"Parses the extended &quot;Date and time of day&quot; format described by RFC 3339. Raises if the format is invalid. For more examples see: from_rfc3339/1. Examples iex&gt; UTCDateTime.from_rfc3339!(&quot;2015-01-23T23:50:07.123Z&quot;) ~Z[2015-01-23 23:50:07.123] iex&gt; UTCDateTime.from_rfc3339!(&quot;2015-01-23T23:50:07,123Z&quot;) ~Z[2015-01-23 23:50:07.123] iex&gt; UTCDateTime.from_rfc3339!(&quot;2015-01-23P23:50:07&quot;) ** (ArgumentError) cannot parse &quot;2015-01-23P23:50:07&quot; as UTC datetime, reason: :invalid_format"},{"ref":"UTCDateTime.html#sigil_Z/2","title":"UTCDateTime.sigil_Z/2","type":"macro","doc":"Handles the sigil ~Z to create a UTCDateTime. By default, this sigil requires UTC date times to be written in the ISO8601 format: ~Z[yyyy-mm-dd hh:mm:ssZ] ~Z[yyyy-mm-dd hh:mm:ss.ssssssZ] ~Z[yyyy-mm-ddThh:mm:ss.ssssss+00:00] such as: ~Z[2015-01-13 13:00:07Z] ~Z[2015-01-13T13:00:07.123+00:00] The given utc_datetime_string must include &quot;Z&quot; or &quot;00:00&quot; offset which marks it as UTC, otherwise an error is raised. The lower case ~z variant does not exist as interpolation and escape characters are not useful for date time sigils. More information on date times can be found in the UTCDateTime module. Examples iex&gt; ~Z[2015-01-13 13:00:07Z] ~Z[2015-01-13 13:00:07Z] iex&gt; ~Z[2015-01-13T13:00:07.001+00:00] ~Z[2015-01-13 13:00:07.001Z]"},{"ref":"UTCDateTime.html#to_date/2","title":"UTCDateTime.to_date/2","type":"function","doc":"Converts a UTCDateTime into a Date. Because Date does not hold time information, data will be lost during the conversion. Because the given utc_datetime does not contain calendar information, a calendar can be given, but will default to Calendar.ISO. Examples iex&gt; UTCDateTime.to_date(~Z[2002-01-13 23:00:07]) ~D[2002-01-13]"},{"ref":"UTCDateTime.html#to_datetime/2","title":"UTCDateTime.to_datetime/2","type":"function","doc":"Converts the given UTCDateTime to NaiveDateTime. The given utc_datetime does not contain a calendar, so Calendar.ISO is set by default. It is possible to manually pass a different calendar. Examples iex&gt; UTCDateTime.to_datetime(~Z[2016-05-24 13:26:08.003]) ~U[2016-05-24 13:26:08.003Z]"},{"ref":"UTCDateTime.html#to_erl/1","title":"UTCDateTime.to_erl/1","type":"function","doc":"Converts a UTCDateTime struct to an Erlang datetime tuple. WARNING: Loss of precision may occur, as Erlang time tuples only store hour/minute/second and the given utc_datetime could contain microsecond precision time data. Examples iex&gt; UTCDateTime.to_erl(~Z[2000-01-01 13:30:15]) {{2000, 1, 1}, {13, 30, 15}}"},{"ref":"UTCDateTime.html#to_iso8601/1","title":"UTCDateTime.to_iso8601/1","type":"function","doc":"Converts the given utc_datetime to ISO 8601:2004. Examples iex&gt; UTCDateTime.to_iso8601(~Z[2019-12-14 08:06:24.289659]) &quot;2019-12-14T08:06:24.289659Z&quot; iex&gt; UTCDateTime.to_iso8601(~Z[2019-12-14 08:06:24]) &quot;2019-12-14T08:06:24Z&quot;"},{"ref":"UTCDateTime.html#to_naive/2","title":"UTCDateTime.to_naive/2","type":"function","doc":"Converts the given UTCDateTime into a NaiveDateTime. The given utc_datetime does not contain a calendar, so Calendar.ISO is set by default. It is possible to manually pass a different calendar. Examples iex&gt; dt = %UTCDateTime{year: 2016, month: 5, day: 24, ...&gt; hour: 13, minute: 26, second: 8, ...&gt; microsecond: {3000, 3}} iex&gt; UTCDateTime.to_naive(dt) ~N[2016-05-24 13:26:08.003]"},{"ref":"UTCDateTime.html#to_rfc3339/1","title":"UTCDateTime.to_rfc3339/1","type":"function","doc":"Converts the given utc_datetime to RFC3339. Examples iex&gt; UTCDateTime.to_rfc3339(~Z[2019-12-14 08:06:24.289659]) &quot;2019-12-14T08:06:24.289659Z&quot; iex&gt; UTCDateTime.to_rfc3339(~Z[2019-12-14 08:06:24]) &quot;2019-12-14T08:06:24Z&quot;"},{"ref":"UTCDateTime.html#to_string/1","title":"UTCDateTime.to_string/1","type":"function","doc":"Converts the given utc_datetime to a string using the format defined by RFC 3339. For more examples see: to_rfc3339/1. Examples iex&gt; UTCDateTime.to_string(~Z[2000-02-28 23:00:13]) &quot;2000-02-28T23:00:13Z&quot; iex&gt; UTCDateTime.to_string(~Z[2000-02-28 23:00:13.001]) &quot;2000-02-28T23:00:13.001Z&quot;"},{"ref":"UTCDateTime.html#to_time/2","title":"UTCDateTime.to_time/2","type":"function","doc":"Converts a UTCDateTime into Time. Because Time does not hold date information, data will be lost during the conversion. Because the given utc_datetime does not contain calendar information, a calendar can be given, but will default to Calendar.ISO. Examples iex&gt; UTCDateTime.to_time(~Z[2002-01-13 23:00:07]) ~T[23:00:07]"},{"ref":"UTCDateTime.html#truncate/2","title":"UTCDateTime.truncate/2","type":"function","doc":"Returns the given utc_datetime with the microsecond field truncated to the given precision (:microsecond, :millisecond or :second). The given naive datetime is returned unchanged if it already has lower precision than the given precision. Examples iex&gt; UTCDateTime.truncate(~Z[2017-11-06 00:23:51.123456], :microsecond) ~Z[2017-11-06 00:23:51.123456] iex&gt; UTCDateTime.truncate(~Z[2017-11-06 00:23:51.123456], :millisecond) ~Z[2017-11-06 00:23:51.123] iex&gt; UTCDateTime.truncate(~Z[2017-11-06 00:23:51.123456], :second) ~Z[2017-11-06 00:23:51]"},{"ref":"UTCDateTime.html#utc_now/0","title":"UTCDateTime.utc_now/0","type":"function","doc":"Returns the current UTC datetime. Examples iex&gt; utc_datetime = UTCDateTime.utc_now() iex&gt; utc_datetime.year &gt;= 2016 true"},{"ref":"UTCDateTime.html#t:epoch/0","title":"UTCDateTime.epoch/0","type":"type","doc":"Common datetime epochs. Epochs EpochDateAliases :go0001-01-01:dotnet, :rata_die, :rexx :uuid1582-10-15 :win1601-01-01:win_nt, :win32, :cobol, :ntfs :mumps1840-12-31 :vms1858-11-17:vms, :usno, :dvb, :mjd :pascal1899-12-30:ms_com, :libre_office_calc, :google_sheets :ms_c1899-12-31:dyalog_alp :ms_excel1900-01-00:ms_excel, :lotus :unix1970-01-01:posix"},{"ref":"UTCDateTime.html#t:t/0","title":"UTCDateTime.t/0","type":"type","doc":"A datetime implementation constraint to UTC."},{"ref":"readme.html","title":"UTC DateTime","type":"extras","doc":"UTC DateTime A datetime implementation constraint to UTC."},{"ref":"readme.html#goal","title":"UTC DateTime - Goal","type":"extras","doc":"The goal is to create datetime type, which unlike DateTime guarantees to be UTC only, without ignoring the existence of timezones like a NaiveDateTime. A secondary goal is to be more efficient or at least on par with the build in datetimes. (DateTime, NaiveDateTime) In practice the goal is to use less memory and perform common [shared] actions faster."},{"ref":"readme.html#quick-setup","title":"UTC DateTime - Quick Setup","type":"extras","doc":"iex&gt; UTCDateTime.utc_now ~Z[2019-12-14 16:08:13.042407] iex&gt; UTCDateTime.from_rfc3339!(&quot;2019-12-14T16:08:13.042407+01:00&quot;) ~Z[2019-12-14 15:08:13.042407] iex&gt; UTCDateTime.from_iso8601!(&quot;2019-12-14 16:08:13.042407&quot;) ~Z[2019-12-14 16:08:13.042407]"},{"ref":"readme.html#installation","title":"UTC DateTime - Installation","type":"extras","doc":"The package can be installed by adding utc_datetime to your list of dependencies in mix.exs: def deps do [ {:utc_datetime, &quot;~&gt; 0.0.7&quot;} ] end The docs can be found at https://hexdocs.pm/utc_datetime."},{"ref":"readme.html#integration","title":"UTC DateTime - Integration","type":"extras","doc":"Ecto Integrates with Ecto as a timestamp type. Example: defmodule User do use Ecto.Schema @timestamps_opts [type: UTCDateTime] schema &quot;users&quot; do field :name, :string timestamps() end ... or alternatively schema &quot;users&quot; do field :name, :string timestamps(type: UTCDateTime) end Jason Integrates with Jason and supports out of the box encoding almost twice as fast as the build in DateTime and NaiveDateTime. Example: iex&gt; Jason.encode!(%{created_at: ~Z[2019-12-16 00:00:12.068421]}) &quot;{\\&quot;created_at\\&quot;:\\&quot;2019-12-16T00:00:12.068421Z\\&quot;}&quot; TimeMachinex Integrates with TimeMachinex and can be used through TimeMachinex.utc_now/1. Example: iex&gt; TimeMachinex.utc_now ~Z[2019-12-16 00:00:12.068421]"},{"ref":"readme.html#changelog","title":"UTC DateTime - Changelog","type":"extras","doc":"v0.0.8 (2019-12-20) New Features: add/2, add/3 diff/2, diff3 Fixes: Allow negative years in ISO 8601. Cleanup: truncate/2 v0.0.7 (2019-12-16) New Features: truncate/2 v0.0.6 (2019-12-15) New Features: Jason [encoding] integration. v0.0.5 (2019-12-15) New Features: Ecto type integration. v0.0.4 (2019-12-15) New Features: compare/2 from_date/2 from_erl/2, from_erl!/2 to_date/2 to_erl/1 to_time/2 v0.0.3 (2019-12-15) New Features: Epochs v0.0.2 (2019-12-15) New Features: ~Z sigil for UTCDateTime from_iso8601/1, from_iso8601!/1 (ISO 8601:2004) from_rfc3339/1, from_rfc3339!/1 (RFC 3339) to_iso8601/1 (ISO 8601:2004) to_rfc3339/1 (RFC 3339) to_string/1 (including String.Chars protocol) v0.0.1 (2019-12-14) Base UTCDateTime. New Features: from_datetime/1 from_naive/1 to_datetime/1, to_datetime/2 to_naive/1, to_naive/2 utc_now/0 Experimental: ~Z sigil for UTCDateTime RFC3339 support Additional: Benchmarks Roadmap"},{"ref":"readme.html#roadmap","title":"UTC DateTime - Roadmap","type":"extras","doc":"Integrations :fixtures Release 0.0.8 Diff Benchmarks Release 0.0.9 To Unix To windows to_epoch(epoch, time_unit) Benchmarks Release 0.0.10 to_local_datetime/1 (in caller) Release 0.0.11 from_human/1 best effort parse"},{"ref":"readme.html#copyright-and-license","title":"UTC DateTime - Copyright and License","type":"extras","doc":"Copyright (c) 2019, Ian Luites. UTCDateTime code is licensed under the MIT License."}]